@@ -12,6 +12,8 @@ from wemake_python_styleguide.visitors.tokenize import (
 PRESET: Final = (
     comments.WrongCommentVisitor,
     comments.ShebangVisitor,
+    comments.NoqaVisitor,
+    comments.EmptyCommentVisitor,
 
     syntax.WrongKeywordTokenVisitor,
 
@@ -21,6 +23,8 @@ PRESET: Final = (
 
     statements.ExtraIndentationVisitor,
     statements.BracketLocationVisitor,
+    statements.MultilineStringVisitor,
+    statements.InconsistentComprehensionVisitor,
 
     conditions.IfElseVisitor,
 )
